<!DOCTYPE html>
<html lang="pl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Nowy Dokument - QRA</title>
    <link rel="stylesheet" href="styles.css">
</head>
<body>
    <header>
        <h1>Nowy Dokument</h1>
        <p class="subtitle">Utworzony przez QRA Editor</p>
    </header>

    <main>
        <section>
            <h2>Witaj w edytorze QRA!</h2>
            <p>Ten dokument został automatycznie utworzony. Możesz teraz:</p>
            <ul>
                <li>Edytować ten HTML w edytorze</li>
                <li>Modyfikować style CSS</li>
                <li>Dodawać nowe pliki</li>
                <li>Oglądać podgląd na żywo</li>
            </ul>
        </section>

        <section>
            <h2>Szybki start</h2>
            <p>Wybierz plik z listy po lewej stronie i zacznij edycję!</p>
        </section>
    </main>

    <footer>
        <p>Automatycznie zapisywane co 5 sekund</p>
    </footer>

    <script src="script.js"></script>
</body>
</html>