/* Portfolio Template */
* { margin: 0; padding: 0; box-sizing: border-box; }

body {
    font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
    line-height: 1.6;
    color: #333;
}

.container { max-width: 1200px; margin: 0 auto; padding: 0 2rem; }

/* Navigation */
nav {
    background: #fff;
    box-shadow: 0 2px 20px rgba(0,0,0,0.1);
    position: fixed;
    width: 100%;
    top: 0;
    z-index: 1000;
}

.nav-container {
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 1rem 2rem;
}

.logo { color: #007bff; }

.nav-menu {
    display: flex;
    list-style: none;
    gap: 2rem;
}

.nav-menu a {
    text-decoration: none;
    color: #333;
    font-weight: 500;
    transition: color 0.3s;
}

.nav-menu a:hover { color: #007bff; }

/* Hero Section */
.hero {
    background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
    color: white;
    height: 100vh;
    display: flex;
    align-items: center;
    justify-content: center;
    text-align: center;
}

.hero h1 { font-size: 3rem; margin-bottom: 1rem; }
.highlight { color: #ffd700; }
.hero p { font-size: 1.2rem; margin-bottom: 2rem; }

.cta-btn {
    display: inline-block;
    background: #ffd700;
    color: #333;
    padding: 1rem 2rem;
    text-decoration: none;
    border-radius: 5px;
    font-weight: bold;
    transition: transform 0.3s;
}

.cta-btn:hover { transform: translateY(-3px); }

/* Sections */
section { padding: 5rem 0; }
.about { background: #f8f9fa; }

h2 {
    font-size: 2.5rem;
    margin-bottom: 2rem;
    text-align: center;
    color: #333;
}

/* Projects */
.project-grid {
    display: grid;
    grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
    gap: 2rem;
    margin-top: 3rem;
}

.project-card {
    background: white;
    padding: 2rem;
    border-radius: 10px;
    box-shadow: 0 5px 15px rgba(0,0,0,0.1);
    transition: transform 0.3s;
}

.project-card:hover { transform: translateY(-5px); }

.project-card h3 {
    color: #007bff;
    margin-bottom: 1rem;
}

.tech-stack {
    margin-top: 1rem;
    padding: 0.5rem 1rem;
    background: #e9ecef;
    border-radius: 20px;
    font-size: 0.9rem;
    color: #666;
}

/* Contact */
.contact {
    background: #333;
    color: white;
    text-align: center;
}

/* Responsive */
@media (max-width: 768px) {
    .hero h1 { font-size: 2rem; }
    .nav-menu { flex-direction: column; gap: 1rem; }
    .project-grid { grid-template-columns: 1fr; }
}