/* Blog Template */
* { margin: 0; padding: 0; box-sizing: border-box; }

body {
    font-family: Georgia, 'Times New Roman', serif;
    line-height: 1.7;
    color: #333;
    background: #fafafa;
}

.container {
    max-width: 1200px;
    margin: 0 auto;
    padding: 0 2rem;
    display: grid;
    grid-template-columns: 2fr 1fr;
    gap: 3rem;
}

/* Header */
.site-header {
    background: #2c3e50;
    color: white;
    padding: 3rem 0;
    text-align: center;
    margin-bottom: 3rem;
}

.site-title {
    font-size: 3rem;
    margin-bottom: 0.5rem;
    font-weight: normal;
}

.site-description {
    font-size: 1.2rem;
    opacity: 0.8;
    font-style: italic;
}

/* Post */
.post {
    background: white;
    padding: 3rem;
    border-radius: 8px;
    box-shadow: 0 2px 20px rgba(0,0,0,0.1);
    margin-bottom: 3rem;
}

.post-title {
    font-size: 2.5rem;
    margin-bottom: 1rem;
    color: #2c3e50;
}

.post-meta {
    margin-bottom: 2rem;
    color: #666;
    border-bottom: 1px solid #eee;
    padding-bottom: 1rem;
    font-size: 0.9rem;
}

.post-meta time, 
.post-meta .author {
    margin-right: 1.5rem;
}

.post-content {
    font-size: 1.1rem;
    line-height: 1.8;
}

.post-content h2 {
    margin: 2.5rem 0 1.5rem 0;
    color: #34495e;
    font-size: 1.8rem;
}

.post-content p {
    margin-bottom: 1.5rem;
}

.post-content ul, 
.post-content ol {
    margin: 1.5rem 0;
    padding-left: 2rem;
}

.post-content li {
    margin: 0.8rem 0;
}

blockquote {
    background: #f8f9fa;
    border-left: 4px solid #3498db;
    margin: 2rem 0;
    padding: 1.5rem 2rem;
    font-style: italic;
    color: #555;
    border-radius: 0 4px 4px 0;
}

/* Sidebar */
.sidebar {
    display: flex;
    flex-direction: column;
    gap: 2rem;
}

.widget {
    background: white;
    padding: 2rem;
    border-radius: 8px;
    box-shadow: 0 2px 10px rgba(0,0,0,0.1);
}

.widget h3 {
    margin-bottom: 1.5rem;
    color: #2c3e50;
    border-bottom: 2px solid #3498db;
    padding-bottom: 0.5rem;
    font-size: 1.3rem;
}

.recent-posts {
    list-style: none;
}

.recent-posts li {
    margin: 1rem 0;
    padding: 0.8rem 0;
    border-bottom: 1px solid #eee;
}

.recent-posts a {
    color: #3498db;
    text-decoration: none;
    transition: color 0.3s;
    display: block;
}

.recent-posts a:hover {
    color: #1a73e8;
    text-decoration: underline;
}

/* Responsive */
@media (max-width: 768px) {
    .container {
        grid-template-columns: 1fr;
        padding: 0 1.5rem;
    }

    .post {
        padding: 2rem 1.5rem;
    }

    .site-title {
        font-size: 2.2rem;
    }

    .post-title {
        font-size: 2rem;
    }

    .widget {
        padding: 1.5rem;
    }
}

@media (max-width: 480px) {
    .site-title {
        font-size: 1.8rem;
    }

    .post-title {
        font-size: 1.6rem;
    }
    
    .post-content h2 {
        font-size: 1.5rem;
    }
}
